/*-------------------------------------------------------------------------
 *
 *   FILE
 *	pqxx/all.h
 *
 *   DESCRIPTION
 *      Convenience header: include all libpqxx definitions
 *
 * Copyright (c) 2003, Jeroen T. Vermeulen <jtv@xs4all.nl>
 *
 *-------------------------------------------------------------------------
 */
#include <pqxx/cachedresult.h>
#include <pqxx/connection.h>
#include <pqxx/cursor.h>
#include <pqxx/largeobject.h>
#include <pqxx/transaction.h>
#include <pqxx/nontransaction.h>
#include <pqxx/robusttransaction.h>
#include <pqxx/transactor.h>
#include <pqxx/tablereader.h>
#include <pqxx/tablewriter.h>
#include <pqxx/trigger.h>

